
*****************
***  Code explanation  ***
*****************
* This code uses two source databases. They come from the 2016 French Labor Survey The data bases are:
*1) individus_ao_rps2016_quetelet
*2) menage2016

*****************
***  AO 2016  ***
*****************
global main = ""
use "$main\sources\individus_ao_rps2016_quetelet", clear

*********************************
*** Individual selection ***
*********************************

*** employees
keep if inlist(statut,"1","2","3","4","5","6","7") 
*** Metropolitan France
keep if region>"06" 
*** 15-64 years
keep if age>=15 & age<=64

*********************
***  Corrections  ***
*********************

*** Age and year of birth problems
replace age = age-100 if age>100
replace anais = anais+100 if anais<1900

*** Correction of the respondent's income revmens
gen     revmens_cor = revmens if revmens<=10000
replace revmens_cor = revmens/10 if inlist(ident_ind,"030015020100001","040000461100001","110001360100001","110002570200001","110003911100002","110018650100001")
replace revmens_cor = revmens/10 if inlist(ident_ind,"210006270100001","230009640100002","250000040300001","250000150100002","310003820100001","530000560500001")
replace revmens_cor = revmens/10 if inlist(ident_ind,"530001580400001","730009550100002","730009570100002","730010920100002","820003810100001","910011160100001")
gen lrevmens=log(revmens+1)

*******************************
*** Variable Creation ***
*******************************

*** Woman
gen     femme = (sexe=="2")
label define femmelabel 1 "femme" 0 "homme"
label values femme femmelabel

** Number of respondent's children in the household
gen     nb_enfant=nbenfm3+nbenf3a17+nbenf18p

*** Cohabiting couple
gen couple1 = (couple=="1") // en couple cohabitant

*** Highest degree
gen dip1 = inlist(diplome,"0","1","2","3") // Inf au Bac
gen dip2 = inlist(diplome,"4","5") // Bac général, technologique ou professionnel
gen dip3 = inlist(diplome,"6","7") // Bac+2 ou Bac+3 ou Bac+4
gen dip4 = inlist(diplome,"8") // Bac+5 ou plus
drop diplome

*** Employment status
gen statut_p1 = inlist(statut,"1","2","3","5") 
label variable statut_p1 "Public"
gen statut_p2 = inlist(statut,"4","6","7","8","9","10")
label variable statut_p2 "Privé"

** Employment type Permanent/Fixed-term
gen dure_indet=inlist(typemploi,"6")  // EDI
gen dure_det=inlist(typemploi,"1","2", "3", "4","5","7") // EDL, intérim, sans contrat, apretis, stage, contrat aide
replace tpp="1" if tpp=="9"
tab tpp, gen(dure)

*** Number of employees in companies
destring nbsala, replace
gen nbsal_10=(nbsala==1 | nbsala==2)
gen nbsal_50=(nbsala==3 | nbsala==4)
gen nbsal_500=(nbsala==5 | nbsala==6)
gen nbsal_1000=(nbsala==7 )
gen nbsal_1000p=(nbsala==8)
gen nbsal_NA=(nbsala==998 | nbsala==99 | nbsala==.)
drop  nbsala


**** Housework
gen dom_cont=1 if domest=="1"
replace dom_cont=4.5 if domest=="2"
replace dom_cont=8 if domest=="3"
replace dom_cont=11 if domest=="4"
replace dom_cont=13 if domest=="5"
label var dom_cont "NbH Domestique"
gen dom_fem=dom_cont*femme
label var dom_fem "NbH Dom * Femme"
	destring domest, replace
	drop if domest>7
	tab domest, gen(domest_)



**  Variable Horaire Atypiques
****************
*** 1. Que horaires atypiques : matin ET/OU soir ET/OU nuit (approche autodéclarative, au moins 1 habituellement)
gen hor_atyp=(ptmatin=="1" | soir=="1" | nuit=="1") & (samedi!="1" & dimanche!="1") 
*** 3. Que jours atypiques (samedi ET/OU dimanche), autodécl
gen jour_atyp=(ptmatin!="1" & soir!="1" & nuit!="1") & (samedi=="1" | dimanche=="1") 
*** 4. Horaire + jour atypique (autodeclarative)
gen hor_et_jour_atyp=(ptmatin=="1" | soir=="1" | nuit=="1") & (samedi=="1" | dimanche=="1") 
*** 5. Ensemble atypiques (horaires et/ou jours)
gen nsws=(ptmatin=="1" | soir=="1" | nuit=="1" | samedi=="1" | dimanche=="1") 
*** 6. Ensemble salariés qui ne sont pas en atypiques habituels
gen regulier=(ptmatin!="1" & soir!="1" & nuit!="1" & samedi!="1" & dimanche!="1")
*** Night shift
gen nuit_hab=(nuit=="1")


**** Create outcome variables
gen wfc=(cvfvp=="3" | cvfvp=="4")

gen lojr=(previs!=1) //*** Previsibility of the schedule - Lack of Job Resource (LOJR)
gen lofr=(indispo=="1" | indispo=="2") //*** Lack of Family Resouces (Complaints by family members)

gen nsws_femme= nsws * femme
gen couple_fem=femme*couple1

**** Situation conjoint
gen cj_emploi=(cjsitua=="1") 
gen cj_chom=(cjsitua=="4") 
gen cj_inactif=(inlist(cjsitua,"2","3","5","6","7","8")) 

save "$main\data\table_2016_selection0", replace


*********************
***  Ménage 2016  ***
*********************


*** Âge du plus jeune enfant
use "$main\sources\menage2016", clear
*** une ligne par ménage avec l'âge du plus jeune enfant 
*** l'individu est enfant du ménage si lien_01="02" ou ... ou lien_20="02"
gen enf_men=(lien_01=="02" | lien_02=="02" | lien_03=="02" | lien_04=="02" | ///
lien_05=="02" | lien_06=="02" | lien_07=="02" | lien_08=="02" | lien_09=="02" | ///
lien_10=="02" | lien_11=="02" | lien_12=="02" | lien_13=="02" | lien_14=="02" | ///
lien_15=="02" | lien_16=="02" | lien_17=="02" | lien_18=="02" | lien_19=="02" | ///
lien_20=="02")
*** On suppose que l'âge du plus jeune enfant est 2016 - anais
gen age_benjamin=2016-real(anais) if enf_men==1  
keep ident_men age_benjamin 
gsort ident_men -age_benjamin 
bysort ident_men: keep if _n==1
merge 1:m ident_men using "$main\Data\table_2016_selection0", nogen keep(matched using)
*** S'il y a plusieurs enquêtés du même ménage, ils ont la même info pour age_benjamin 

replace age_benjamin=1 if age_benjamin==0
replace age_benjamin=0 if age_benjamin==.
gen benjamin_10ans=(age_benjamin<11)

sort ident_ind



***** Build sample variable
gen sample1=1 // All
gen sample2=(femme==1) // Women
gen sample3=(femme==0) // Men

*** Build the interaction terms
gen lofr_femme=lofr*femme
gen lojr_femme=lojr*femme
gen hor_atyp_femme=hor_atyp*femme
gen jour_atyp_femme=jour_atyp*femme
gen hor_et_jour_atyp_femme=hor_et_jour_atyp*femme
gen nuit_hab_femme=nuit_hab*femme

*** Build the categorical variables 
gen wfc_cat=cvfvp
	destring wfc_cat, replace
	replace wfc_cat=. if wfc_cat>4
gen reproche_cat=indispo
	destring reproche_cat, replace
	replace reproche_cat=. if reproche_cat>4
	tab reproche_cat, gen(complain)
gen previs_cat=previs
	destring previs_cat, replace
	replace previs_cat=. if previs_cat>4
	tab previs_cat, gen(predict)
drop complain4 predict1 // drop the two reference categories

	**** Labelisation English
label var femme "Women"
label var age "Age"
label var age_benjamin "Youngest's Age"
label var benjamin_10ans "Youngest child <11"
label var couple1 "Partner"
label var nb_enfant "Num. Children"
label var dure_indet "Permanent Contract"
label var hh "Hours Worked"
label var dip2 "High School"
label var dip3 "Bachelor"
label var dip4 "Master or higher"
label var nbsal_10 "Comp. Size $<$10"
label var nbsal_50 "Comp. Size 10-50"
label var nbsal_500 "Comp. Size 50-500"
label var nbsal_1000 "Comp. Size 500-1000"
label var nbsal_1000p "Comp. Size $>$1000"
label var statut_p1 "Public Sector"
label var hor_atyp "Horaire Atyp"
label var jour_atyp "Horaire Atyp"
label var hor_et_jour_atyp "Horaire Atyp"
label var nsws "NSWS"
label var dom_cont "Housework (h)"
label var wfc "WFC"

label var nsws_femme "NSWS x Women"
label var cj_emploi "Partner Employed"
label var cj_chom "Partner Unemployed"
label var cj_inactif "Partner Inactive"
label var lofr_femme "LOFR x Women"
label var lojr_femme "LOJR x Women"
label var hor_atyp_femme "NSWS x Women"
label var jour_atyp_femme "NSWS x Women"
label var hor_et_jour_atyp_femme "NSWS x Women"
label var nuit_hab_femme "NSWS x Women"
label var lofr "LOFR"
label var lojr "LOJR"
label var wfc_cat "LoSS categories"
label var previs_cat "Predictability"
label var complain1 "Complains = Always"
label var complain2 "Complains = Often"
label var complain3 "Complains = Sometimes"
label var predict2 "Predictability = Weekly"
label var predict3 "Predictability = Next day"
label var predict4 "Predictability = Never"

save "$main\JFR_data.dta", replace

**************************************************************************************************
****** Building Tables and Figures for the JFR paper *************************************
**************************************************************************************************
use "$main\JFR_data.dta", clear
global Controls femme age  nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1 dom_cont cj_emploi cj_chom cj_inactif

*-------------------------------------------------------------------------------*
*** TABLE 1: Descriptive statistics by type of schedule 
*-------------------------------------------------------------------------------*
use "$main\JFR_data", clear

*** Sample selection 
keep if couple1==1 // sample: only people with a partner
keep if  cjsitua!=""
keep if nb_enfant>0

local variables wfc lofr  lojr femme age nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1
local   n_var=wordcount("`variables'") + 2   // number of variables
mat             T=J(`n_var',6,.)                                // number of rows, number of columns
 
local   r=0
foreach y in `variables' {
                local ++r
                qui: sum `y' if nsws==0 , meanonly 
                mat T[`r',1]=round(r(mean), 0.0001)*100 //mean  Men NSWS
                qui: sum `y' if nsws==1 , meanonly 
                mat T[`r',2]=round(r(mean), 0.0001)*100 //mean  Men NSWS
                qui: sum `y' if hor_atyp==1 , meanonly 
                mat T[`r',3]=round(r(mean), 0.0001)*100  //mean  Women NSWS
                qui: sum `y' if jour_atyp==1 , meanonly 
                mat T[`r',4]=round(r(mean), 0.0001)*100  //mean  Men Standard
                qui: sum `y' if hor_et_jour_atyp==1 , meanonly 
                mat T[`r',5]=round(r(mean), 0.0001)*100  //mean  Women Standard 
                qui: sum `y' if nuit_hab==1 , meanonly 
				mat T[`r',6]=round(r(mean), 0.0001)*100  //mean  Women Standard 
	}
	
			qui: sum nsws if nsws==0
				mat T[wordcount("`variables'") + 1,1]= r(N)
				qui: sum nsws
				mat T[wordcount("`variables'") + 2,1]= (1- round(r(mean), 0.0001))*100
			qui: sum nsws if nsws==1
				mat T[wordcount("`variables'") + 1,2]= r(N)
				qui: sum nsws
				mat T[wordcount("`variables'") + 2,2]= round(r(mean), 0.0001)*100
			qui: sum hor_atyp if hor_atyp==1
				mat T[wordcount("`variables'") + 1,3]= r(N)
				qui: sum hor_atyp
				mat T[wordcount("`variables'") + 2,3]= round(r(mean), 0.0001)*100
			qui: sum jour_atyp if jour_atyp==1
				mat T[wordcount("`variables'") + 1,4]= r(N)
				qui: sum jour_atyp
				mat T[wordcount("`variables'") + 2,4]= round(r(mean), 0.0001)*100
			qui: sum hor_et_jour_atyp if hor_et_jour_atyp==1
				mat T[wordcount("`variables'") + 1,5]= r(N)
				qui: sum hor_et_jour_atyp
				mat T[wordcount("`variables'") + 2,5]= round(r(mean), 0.0001)*100
			qui: sum nuit_hab if nuit_hab==1
				mat T[wordcount("`variables'") + 1,6]= r(N)
				qui: sum nuit_hab
				mat T[wordcount("`variables'") + 2,6]= round(r(mean), 0.0001)*100
				
mat     colnames T= "Standard" "Day and/or Hour" "Hour" "Day" "Day and Hour" "Night" 
mat             rownames T  = "WFC" "LoSS" "No predictavility" "Women" "Age" "Children" "Child under 10" "High School" "Bachelor" "Master" "Permanent Contract" "Hours worked" "Public Sector" "N" "Share"
mat             list T	

putexcel set "$main/tables_figures/Table1", modify 
putexcel B3 = matrix(T) ,names


*-------------------------------------------------------------------------------*
*** TABLE 2: Linear probability models of NSWS on WFC, by type of NSWS
*-------------------------------------------------------------------------------*
use "$main\JFR_data", clear
global Controls femme age  nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1 /*dom_cont*/ cj_emploi cj_chom cj_inactif
*** Sample selection 
keep if couple1==1 // sample: only people with a partner
keep if  cjsitua!=""
keep if nb_enfant>0

*** Women
	preserve
	keep if femme==1
reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Controls, Yes, Measure, Hours) replace dec(3) label	
	drop nsws 
	rename hor_atyp nsws
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Controls, Yes, Measure, Hours) append dec(3) label	
	drop nsws 
	rename jour_atyp nsws
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Controls, Yes, Measure, Weekend) append dec(3) label	
	drop nsws 
	rename hor_et_jour_atyp nsws
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Controls, Yes, Measure, Hours & Weekend) append dec(3) label	
	drop nsws 
	rename nuit_hab nsws
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Measure, Night shift) append dec(3) label	
	restore
*** Men	
	preserve
	keep if femme==0
reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Controls, Yes, Measure, Hours) append dec(3) label	
	drop nsws 
	rename hor_atyp nsws
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Controls, Yes, Measure, Hours) append dec(3) label	
	drop nsws 
	rename jour_atyp nsws
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Controls, Yes, Measure, Weekend) append dec(3) label	
	drop nsws 
	rename hor_et_jour_atyp nsws
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Controls, Yes, Measure, Hours & Weekend) append dec(3) label	
	drop nsws 
	rename nuit_hab nsws
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table2" ,  excel tex keep(nsws femme nsws_femme lofr lojr)  addtext(Measure, Night shift) append dec(3) label	
	restore
	
	
*-------------------------------------------------------------------------------*
*** TABLE 3: Work–family conflict, lack of family resources, and lack of job resources by schedule type and gender
*-------------------------------------------------------------------------------*
use "$main\JFR_data", clear
global Controls femme age  nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1 /*dom_cont*/ cj_emploi cj_chom cj_inactif
*** Sample selection 
keep if couple1==1 // sample: only people with a partner
keep if  cjsitua!=""
keep if nb_enfant>0

reg wfc i.femme##i.nsws
reg lojr i.femme##i.nsws
reg lofr i.femme##i.nsws

local variables   wfc lojr lofr
local   n_var=wordcount("`variables'")   // number of variables
mat             T=J(`n_var',6,.)                                // number of rows, number of columns
 
local   r=0
foreach var in `variables' {
 local ++r
                qui: sum `var' if femme==0 & nsws==1, meanonly 
                mat T[`r',1]=round(r(mean), 0.0001)*100 //mean  Men NSWS
                qui: sum `var' if femme==1 & nsws==1, meanonly 
                mat T[`r',2]=round(r(mean), 0.0001)*100  //mean  Women NSWS
                qui: sum `var' if femme==0 & nsws==0, meanonly 
                mat T[`r',3]=round(r(mean), 0.0001)*100 //mean  Men NSWS
                qui: sum `var' if femme==1 & nsws==0, meanonly 
                mat T[`r',4]=round(r(mean), 0.0001)*100  //mean  Women NSWS	
				mat T[`r',5]= T[`r',1] - T[`r',3] // difference M NSWS - Standard
				mat T[`r',6]=T[`r',2] - T[`r',4]  // difference W NSWS - Standard
				  } 
mat     colnames T= "Men" "Woman"  "Men" "Woman"  "Men" "Woman"
mat             rownames T  = "WFC" "LOFR" "LOJR" 
mat             list T	

putexcel set "$main/tables_figures/SD_HA_HF_dip", modify sheet("`y'")
putexcel B3 = matrix(T) ,names	



*-------------------------------------------------------------------------------*
*** TABLE 4: Linear probability models of NSWS on WFC, the role of LOJR and LOFR
*-------------------------------------------------------------------------------*
use "$main\JFR_data", clear
global Controls femme age  nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1 /*dom_cont*/ cj_emploi cj_chom cj_inactif

*** Sample selection 
keep if couple1==1 // sample: only people with a partner
keep if  cjsitua!=""
keep if nb_enfant>0

	preserve
	keep if femme==1
reg wfc nsws  $Controls   , robust 
		outreg2 using "$main/tables_figures/Table4" ,  excel tex keep(nsws 	femme nsws_femme)  addtext(Controls, Yes) replace dec(3) label	
reg wfc nsws  $Controls   lojr   , robust 
		outreg2 using "$main/tables_figures/Table4" ,  excel tex keep(nsws femme nsws_femme  lojr)   addtext(Controls, Yes) append dec(3) label	
	reg wfc nsws  $Controls lofr  , robust 
		outreg2 using "$main/tables_figures/Table4" ,  excel tex keep(nsws femme nsws_femme lofr)   addtext(Controls, Yes) append dec(3) label	
	restore
	preserve
	keep if femme==0
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/Table4" ,  excel tex keep(nsws femme nsws_femme)  addtext(Controls, Yes) append dec(3) label	
	reg wfc nsws  $Controls   lojr   , robust 
		outreg2 using "$main/tables_figures/Table4" ,  excel tex keep(nsws femme nsws_femme  lojr)   addtext(Controls, Yes) append dec(3) label	
	reg wfc nsws  $Controls  lofr  , robust 
		outreg2 using "$main/tables_figures/Table4" ,  excel tex keep(nsws femme nsws_femme lofr)   addtext(Controls, Yes) append dec(3) label	
	restore
	
	
*-------------------------------------------------------------------------------*
*** TABLE A1: Multinomial logit models of NSWS on a categorical measure of WFC 
*-------------------------------------------------------------------------------*
use "$main\JFR_data", clear
global Controls  age  nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1 /*dom_cont*/ cj_emploi cj_chom cj_inactif

*** Sample selection 
keep if couple1==1 // sample: only people with a partner
keep if  cjsitua!=""
keep if nb_enfant>0
			preserve
	keep if femme==1
	mlogit wfc_cat nsws  $Controls  , b(1) rrr
		outreg2 using "$main/tables_figures/TableA1" , eform cti(odds ratio) excel tex keep(nsws )  addtext(Controls, Yes) replace dec(3) label	
	restore
	preserve
	keep if femme==0
	mlogit wfc_cat nsws  $Controls , b(1) rrr
		outreg2 using "$main/tables_figures/TableA1" , eform cti(odds ratio) excel tex keep(nsws )  addtext(Controls, Yes) append dec(3) label	
	restore
	
	
*-------------------------------------------------------------------------------*
*** TABLE A2: Linear probability models of NSWS on WFC, both genders together
*-------------------------------------------------------------------------------* 
use "$main\JFR_data", clear
global Controls  age  nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1 /*dom_cont*/ cj_emploi cj_chom cj_inactif

*** Sample selection 
keep if couple1==1 // sample: only people with a partner
keep if  cjsitua!=""
keep if nb_enfant>0

	reg wfc nsws femme nsws_femme $Controls    , robust 
		outreg2 using "$main/tables_figures/TableA2" ,  excel tex keep(nsws femme nsws_femme)  addtext(Controls, Yes) replace dec(3) label
	reg wfc nsws  femme lojr lojr_femme $Controls    ,  
		outreg2 using "$main/tables_figures/TableA2" ,  excel tex keep(nsws femme nsws_femme lojr lojr_femme)   addtext(Controls, Yes) append dec(3) label	
	reg wfc nsws femme lofr lofr_femme $Controls    , robust 
		outreg2 using "$main/tables_figures/TableA2" ,  excel tex keep(nsws femme lofr lofr_femme)   addtext(Controls, Yes) append dec(3) label	

	
	
*-------------------------------------------------------------------------------*
*** TABLE A3: Linear probability models with all control variables
*-------------------------------------------------------------------------------*
use "$main\JFR_data", clear
global Controls  age  nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1 /*dom_cont*/ cj_emploi cj_chom cj_inactif

*** Sample selection 
keep if couple1==1 // sample: only people with a partner
keep if  cjsitua!=""
keep if nb_enfant>0

	preserve
	keep if femme==1
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/TableA3" ,  excel tex  addtext(Controls, Yes) replace dec(3) label	
	reg wfc nsws  $Controls  lojr  , robust 
		outreg2 using "$main/tables_figures/TableA3" ,  excel tex  addtext(Controls, Yes) append dec(3) label	
	reg wfc nsws  $Controls   lofr   , robust 
		outreg2 using "$main/tables_figures/TableA3" ,  excel tex    addtext(Controls, Yes) append dec(3) label	
	restore
	preserve
	keep if femme==0
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/TableA3" ,  excel tex  addtext(Controls, Yes) append dec(3) label	
	reg wfc nsws  $Controls  lojr  , robust 
		outreg2 using "$main/tables_figures/TableA3" ,  excel tex   addtext(Controls, Yes) append dec(3) label	
	reg wfc nsws  $Controls   lofr   , robust 
		outreg2 using "$main/tables_figures/TableA3" ,  excel tex   addtext(Controls, Yes) append dec(3) label	
	restore

	
*-------------------------------------------------------------------------------*
*** TABLE A4: Linear probability models of NSWS on WFC, the role of family resources  (complaints) and job resources (schedule predictability) as categorical variables
*-------------------------------------------------------------------------------*
use "$main\JFR_data", clear
global Controls  age  nb_enfant benjamin_10ans dip2 dip3 dip4 dure_indet hh statut_p1 /*dom_cont*/ cj_emploi cj_chom cj_inactif

*** Sample selection 
keep if couple1==1 // sample: only people with a partner
keep if  cjsitua!=""
keep if nb_enfant>0
	preserve
	keep if femme==1
	reg wfc nsws  $Controls    , robust 
		outreg2 using "$main/tables_figures/TableA4" ,  excel tex keep(nsws )  addtext(Controls, Yes) replace dec(3) label	
	reg wfc nsws  $Controls   predict*   , robust 
		outreg2 using "$main/tables_figures/TableA4" ,  excel tex keep(nsws predict*)   addtext(Controls, Yes) append dec(3) label
		reg wfc nsws  $Controls complain*  , robust 
		outreg2 using "$main/tables_figures/TableA4" ,  excel tex keep(nsws complain*)   addtext(Controls, Yes) append dec(3) label	
	
	restore
	preserve
	keep if femme==0
	reg wfc nsws  $Controls   , robust 
		outreg2 using "$main/tables_figures/TableA4" ,  excel tex keep(nsws )  addtext(Controls, Yes) append dec(3) label	
	reg wfc nsws  $Controls   predict*   , robust 
		outreg2 using "$main/tables_figures/TableA4" ,  excel tex keep(nsws predict*)   addtext(Controls, Yes) append dec(3) label
	reg wfc nsws  $Controls  complain*  , robust 
		outreg2 using "$main/tables_figures/TableA4" ,  excel tex keep(nsws complain*)   addtext(Controls, Yes) append dec(3) label	
	restore
	
	